diff --git a/src/gui/qgsmaptip.cpp b/src/gui/qgsmaptip.cpp
index 8c45590..92afbce 100644
--- a/src/gui/qgsmaptip.cpp
+++ b/src/gui/qgsmaptip.cpp
@@ -18,6 +18,7 @@
 #include <qgsvectordataprovider.h>
 #include <qgsvectorlayer.h>
 #include <qgsfield.h>
+#include <qgscoordinatetransform.h>
 
 // Qt includes
 #include <QPoint>
@@ -84,6 +85,21 @@ QString QgsMapTip::fetchFeature( QgsMapLayer *layer, QgsPoint & mapPosition, Qgs
   // Protection just in case we get passed a null layer
   if ( layer )
   {
+  
+    //Reproject coordinates if on-the-fly-reprojection is on
+    if ( mpMapCanvas->hasCrsTransformEnabled() )
+    {
+      long layerCrs = layer->crs().srsid();
+      long mapCanvasCrs = mpMapCanvas->mapRenderer()->destinationCrs().srsid();
+		
+      if ( layerCrs != mapCanvasCrs )
+      {
+        QgsPoint transPoint = QgsCoordinateTransform( mapCanvasCrs, layerCrs ).transform( mapPosition );
+        mapPosition.setX( transPoint.x() );
+        mapPosition.setY( transPoint.y() );
+      }
+	  }
+
     // Get the setting for the search radius from user preferences, if it exists
     QSettings settings;
     double identifyValue = settings.value( "/Map/identifyRadius", QGis::DEFAULT_IDENTIFY_RADIUS ).toDouble();
